@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2022 Gentoo Foundation
+ * Copyright 2005-2023 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2005-2008 Ned Ludd        - <solar@gentoo.org>
@@ -297,7 +297,8 @@ tree_open_cat(tree_ctx *ctx, const char *name)
 	cat_ctx->pkg_cnt = 0;
 
 	if (ctx->cache.categories != NULL) {
-		add_set_value(name, cat_ctx, ctx->cache.categories);
+		ctx->cache.categories =
+			add_set_value(name, cat_ctx, NULL, ctx->cache.categories);
 		/* ensure name doesn't expire after this instantiation is closed */
 		cat_ctx->name = contains_set(name, ctx->cache.categories);
 	}
@@ -824,6 +825,7 @@ tree_read_file_md5(tree_pkg_ctx *pkg_ctx)
 		assign_var(DEFINED_PHASES);
 		assign_var(REQUIRED_USE);
 		assign_var(BDEPEND);
+		assign_var(IDEPEND);
 		assign_var(EPREFIX);
 		assign_var(_eclasses_);
 		assign_var(_md5_);
@@ -901,6 +903,7 @@ tree_read_file_ebuild(tree_pkg_ctx *pkg_ctx)
 			match_key(EAPI);
 			match_key(REQUIRED_USE);
 			match_key(BDEPEND);
+			match_key(IDEPEND);
 #undef match_key
 		}
 
@@ -1004,6 +1007,7 @@ tree_read_file_binpkg_xpak_cb(
 	match_path(DEFINED_PHASES);
 	match_path(REQUIRED_USE);
 	match_path(BDEPEND);
+	match_path(IDEPEND);
 	match_path(CONTENTS);
 	match_path(USE);
 	match_path(EPREFIX);
@@ -1513,6 +1517,7 @@ tree_foreach_packages(tree_ctx *ctx, tree_pkg_cb callback, void *priv)
 		match_key2(REPO, repository);
 		match_key(SIZE);
 		match_key(BDEPEND);
+		match_key(IDEPEND);
 		match_key(PATH);
 		match_key2(BUILD_ID, BUILDID);
 #undef match_key
@@ -1704,7 +1709,8 @@ tree_match_atom_cache_populate_cb(tree_pkg_ctx *ctx, void *priv)
 	cat_ctx = get_set(atom->CATEGORY, cache);
 	if (cat_ctx == NULL) {
 		cat_ctx = tree_open_cat(tctx, ".");
-		add_set_value(atom->CATEGORY, cat_ctx, cache);
+		if (cache != NULL)  /* for static code analysers */
+			add_set_value(atom->CATEGORY, cat_ctx, NULL, cache);
 		/* get a pointer from the set */
 		cat_ctx->name = contains_set(atom->CATEGORY, cache);
 	}
