@@ -1,14 +1,20 @@
 /*
- * Copyright 2005-2018 Gentoo Foundation
+ * Copyright 2005-2019 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2005-2008 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2014 Mike Frysinger  - <vapier@gentoo.org>
  */
 
-#include "tests/tests.h"
+#include "main.h"
+#include "rmspace.h"
 
-#include "libq/rmspace.c"
+#include <stdio.h>
+#include <string.h>
+#include <ctype.h>
+
+const char *argv0;
+FILE *warnout;
 
 int main(int argc, char *argv[])
 {
@@ -16,6 +22,9 @@ int main(int argc, char *argv[])
 	char *s;
 	size_t len;
 
+	argv0 = argv[0];
+	warnout = stderr;
+
 	if (argc <= 1)
 		return 1;
 
